#
# spec file for package perl-Starman
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Starman
Name:           perl-Starman
Version:        0.4017
Release:        1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        High-performance preforking PSGI/Plack web server
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIYAGAWA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Data::Dump)
BuildRequires:  perl(HTTP::Date)
BuildRequires:  perl(HTTP::Parser::XS)
BuildRequires:  perl(HTTP::Status)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(Net::Server) >= 2.007
BuildRequires:  perl(Plack) >= 0.9971
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Test::TCP) >= 2.00
BuildRequires:  perl(parent)
Requires:       perl(Data::Dump)
Requires:       perl(HTTP::Date)
Requires:       perl(HTTP::Parser::XS)
Requires:       perl(HTTP::Status)
Requires:       perl(Net::Server) >= 2.007
Requires:       perl(Plack) >= 0.9971
Requires:       perl(Test::TCP) >= 2.00
Requires:       perl(parent)
%{perl_requires}

%description
Starman is a PSGI perl web server that has unique features such as:

* High Performance

Uses the fast XS/C HTTP header parser

* Preforking

Spawns workers preforked like most high performance UNIX servers do.
Starman also reaps dead children and automatically restarts the worker
pool.

* Signals

Supports 'HUP' for graceful worker restarts, and 'TTIN'/'TTOU' to
dynamically increase or decrease the number of worker processes, as well as
'QUIT' to gracefully shutdown the worker processes.

* Superdaemon aware

Supports Server::Starter for hot deploy and graceful restarts.

* Multiple interfaces and UNIX Domain Socket support

Able to listen on multiple interfaces including UNIX sockets.

* Small memory footprint

Preloading the applications with '--preload-app' command line option
enables copy-on-write friendly memory management. Also, the minimum memory
usage Starman requires for the master process is 7MB and children (workers)
is less than 3.0MB.

* PSGI compatible

Can run any PSGI applications and frameworks

* HTTP/1.1 support

Supports chunked requests and responses, keep-alive and pipeline requests.

* UNIX only

This server does not support Win32.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Thu Sep 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.4017
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4017  2023-09-13 13:27:02 PDT
  - Handle EINTR when doing sysread calls (Rob Mueller) #148
  - Requires perl 5.14
* Wed Sep 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.4016
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4016  2022-09-13 10:11:34 PDT
  - Add psgix.informational callback #146
* Tue May 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.4015
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4015  2019-05-20 18:43:46 PDT
  - Fixed a bug incorrectly handling content body of '0' (olsonanl) #133
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.4014
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4014  2015-06-03 12:01:00 PDT
  - Treat ECONNRESET like EPIPE (i.e. ignore), not as a fatal error #114 (Tim Bunce)
* Fri May 15 2015 coolo@suse.com
- updated to 0.4013
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4013  2015-05-14 15:01:20 PDT
  - Fixed some bad git merges.
  0.4012  2015-05-14 14:59:48 PDT
  - Add --net_server-* options to pass directly to Net::Server backend (#109)
  - Updated documentation
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.4011
  see /usr/share/doc/packages/perl-Starman/Changes
  0.4011  2014-11-11 08:07:43 PST
  - Move the app dispatch into a method #107
  0.4010  2014-08-22 09:37:22 PDT
  - Support --read-timeout #103 (slobo)
  - Handle Expect header case insensitively #101 (oschwald)
* Fri May 23 2014 ncutler@suse.com
- initial package 0.4009
  * created by cpanspec 1.78.07
- took over
- checked License
